#' The 'tsnet' package
#'
#' @description Time Series Network Analysis with R
#'
#' @name tsnet-package
#' @aliases tsnet
#' @useDynLib tsnet, .registration = TRUE
#' @import methods
#' @import Rcpp
#' @importFrom rstan sampling
#' @importFrom rstantools rstan_config
#' @importFrom RcppParallel RcppParallelLibs
#'
#'
"_PACKAGE"
